@@ -60,10 +60,12 @@ from airflow.sdk.execution_time.context import (
     _AssetRefResolutionMixin,
     _async_get_connection,
     _convert_variable_result_to_variable,
+    _get_connection,
     _process_connection_result_conn,
     context_to_airflow_vars,
     set_current_context,
 )
+from airflow.sdk.execution_time.secrets import ExecutionAPISecretsBackend
 
 
 def test_convert_connection_result_conn():
@@ -344,12 +346,13 @@ class TestCurrentContext:
 
 class TestOutletEventAccessor:
     @pytest.mark.parametrize(
-        "add_arg",
+        "add_args",
         [
-            Asset("name", "uri"),
-            Asset.ref(name="name"),
-            Asset.ref(uri="uri"),
+            (Asset("name", "uri", extra={"extra": "from asset itself"}), {"extra": "from event"}),
+            (Asset.ref(name="name"), {"extra": "from event"}),
+            (Asset.ref(uri="uri"), {"extra": "from event"}),
         ],
+        ids=["asset", "asset name ref", "asset uri ref"],
     )
     @pytest.mark.parametrize(
         "key, asset_alias_events",
@@ -361,26 +364,31 @@ class TestOutletEventAccessor:
                     AssetAliasEvent(
                         source_alias_name="test_alias",
                         dest_asset_key=AssetUniqueKey(name="name", uri="uri"),
-                        extra={},
+                        dest_asset_extra={"extra": "from asset itself"},
+                        extra={"extra": "from event"},
                     )
                 ],
             ),
         ),
+        ids=["inactive asset", "active asset"],
     )
-    def test_add(self, add_arg, key, asset_alias_events, mock_supervisor_comms):
-        mock_supervisor_comms.send.return_value = AssetResponse(name="name", uri="uri", group="")
+    def test_add(self, add_args, key, asset_alias_events, mock_supervisor_comms):
+        mock_supervisor_comms.send.return_value = AssetResponse(
+            name="name", uri="uri", group="", extra={"extra": "from asset itself"}
+        )
 
         outlet_event_accessor = OutletEventAccessor(key=key, extra={})
-        outlet_event_accessor.add(add_arg)
+        outlet_event_accessor.add(*add_args)
         assert outlet_event_accessor.asset_alias_events == asset_alias_events
 
     @pytest.mark.parametrize(
-        "add_arg",
+        "add_args",
         [
-            Asset("name", "uri"),
-            Asset.ref(name="name"),
-            Asset.ref(uri="uri"),
+            (Asset(name="name", uri="uri", extra={"extra": "from asset itself"}), {"extra": "from event"}),
+            (Asset.ref(name="name"), {"extra": "from event"}),
+            (Asset.ref(uri="uri"), {"extra": "from event"}),
         ],
+        ids=["asset", "asset name ref", "asset uri ref"],
     )
     @pytest.mark.parametrize(
         "key, asset_alias_events",
@@ -392,17 +400,21 @@ class TestOutletEventAccessor:
                     AssetAliasEvent(
                         source_alias_name="test_alias",
                         dest_asset_key=AssetUniqueKey(name="name", uri="uri"),
-                        extra={},
+                        dest_asset_extra={"extra": "from asset itself"},
+                        extra={"extra": "from event"},
                     )
                 ],
             ),
         ),
+        ids=["inactive asset", "active asset"],
     )
-    def test_add_with_db(self, add_arg, key, asset_alias_events, mock_supervisor_comms):
-        mock_supervisor_comms.send.return_value = AssetResponse(name="name", uri="uri", group="")
+    def test_add_with_db(self, add_args, key, asset_alias_events, mock_supervisor_comms):
+        mock_supervisor_comms.send.return_value = AssetResponse(
+            name="name", uri="uri", group="", extra={"extra": "from asset itself"}
+        )
 
-        outlet_event_accessor = OutletEventAccessor(key=key, extra={"not": ""})
-        outlet_event_accessor.add(add_arg, extra={})
+        outlet_event_accessor = OutletEventAccessor(key=key)
+        outlet_event_accessor.add(*add_args)
         assert outlet_event_accessor.asset_alias_events == asset_alias_events
 
 
@@ -765,3 +777,100 @@ class TestAsyncGetConnection:
             # Should not have tried SUPERVISOR_COMMS since secrets backend had the connection
             mock_supervisor_comms.send.assert_not_called()
             mock_supervisor_comms.asend.assert_not_called()
+
+
+class TestSecretsBackend:
+    """Test that connection resolution uses the backend chain correctly."""
+
+    def test_execution_api_backend_in_worker_chain(self):
+        """Test that ExecutionAPISecretsBackend is in the worker search path."""
+        from airflow.sdk.execution_time.secrets import DEFAULT_SECRETS_SEARCH_PATH_WORKERS
+
+        assert (
+            "airflow.sdk.execution_time.secrets.execution_api.ExecutionAPISecretsBackend"
+            in DEFAULT_SECRETS_SEARCH_PATH_WORKERS
+        )
+
+    def test_metastore_backend_in_server_chain(self):
+        """Test that MetastoreBackend is in the API server search path."""
+        from airflow.secrets import DEFAULT_SECRETS_SEARCH_PATH
+
+        assert "airflow.secrets.metastore.MetastoreBackend" in DEFAULT_SECRETS_SEARCH_PATH
+        assert (
+            "airflow.sdk.execution_time.secrets.execution_api.ExecutionAPISecretsBackend"
+            not in DEFAULT_SECRETS_SEARCH_PATH
+        )
+
+    def test_get_connection_uses_backend_chain(self, mock_supervisor_comms):
+        """Test that _get_connection properly iterates through backends."""
+        from airflow.sdk.api.datamodels._generated import ConnectionResponse
+        from airflow.sdk.execution_time.comms import ConnectionResult
+
+        # Mock connection response
+        conn_response = ConnectionResponse(
+            conn_id="test_conn",
+            conn_type="http",
+            host="example.com",
+            port=443,
+        )
+        conn_result = ConnectionResult.from_conn_response(conn_response)
+        mock_supervisor_comms.send.return_value = conn_result
+
+        # Mock the backend loading to include our SupervisorComms backend
+        supervisor_backend = ExecutionAPISecretsBackend()
+
+        with patch("airflow.sdk.execution_time.supervisor.ensure_secrets_backend_loaded") as mock_load:
+            mock_load.return_value = [supervisor_backend]
+
+            conn = _get_connection("test_conn")
+
+            assert conn is not None
+            assert conn.conn_id == "test_conn"
+            assert conn.host == "example.com"
+            mock_supervisor_comms.send.assert_called_once()
+
+    def test_get_connection_backend_fallback(self, mock_supervisor_comms):
+        """Test that _get_connection falls through backends correctly."""
+        from airflow.sdk.api.datamodels._generated import ConnectionResponse
+        from airflow.sdk.execution_time.comms import ConnectionResult
+
+        # First backend returns nothing (simulating env var backend with no env var)
+        class EmptyBackend:
+            def get_connection(self, conn_id):
+                return None
+
+        # Second backend returns the connection
+        conn_response = ConnectionResponse(
+            conn_id="test_conn",
+            conn_type="postgres",
+            host="db.example.com",
+        )
+        conn_result = ConnectionResult.from_conn_response(conn_response)
+        mock_supervisor_comms.send.return_value = conn_result
+
+        supervisor_backend = ExecutionAPISecretsBackend()
+
+        with patch("airflow.sdk.execution_time.supervisor.ensure_secrets_backend_loaded") as mock_load:
+            mock_load.return_value = [EmptyBackend(), supervisor_backend]
+
+            conn = _get_connection("test_conn")
+
+            assert conn is not None
+            assert conn.conn_id == "test_conn"
+            # SupervisorComms backend was called (first backend returned None)
+            mock_supervisor_comms.send.assert_called_once()
+
+    def test_get_connection_not_found_raises_error(self, mock_supervisor_comms):
+        """Test that _get_connection raises error when no backend finds connection."""
+        from airflow.exceptions import AirflowNotFoundException
+
+        # Backend returns None (not found)
+        class EmptyBackend:
+            def get_connection(self, conn_id):
+                return None
+
+        with patch("airflow.sdk.execution_time.supervisor.ensure_secrets_backend_loaded") as mock_load:
+            mock_load.return_value = [EmptyBackend()]
+
+            with pytest.raises(AirflowNotFoundException, match="isn't defined"):
+                _get_connection("nonexistent_conn")
